@@ -109,7 +109,7 @@
 
 /* Use header-only classes from Boost in the Splash backend */
 #ifndef USE_BOOST_HEADERS
-/* #undef USE_BOOST_HEADERS */
+#define USE_BOOST_HEADERS 1
 #endif
 
 //------------------------------------------------------------------------
